==> nextcloud-jitsi-v0.16.2.tar.gz: jitsi/l10n/sk.js <==
OC.L10N.register(
    "jitsi",
    {
    "conferences" : "konferencie",
    "Jitsi Integration" : "Jitsi integrácia",
    "Conferences" : "Konferencie",
    "Jitsi Integration (unofficial)" : "Jitsi integrácia (neoficiálna)",
    "This app integrates Jitsi conferences into Nextcloud.\n\nFeatures:\n- 🎥 Easy online conferences in Nextcloud utilising Jitsi\n- 🔗 Sharable conference room links\n- 🔎 Shows conference rooms in the global search\n- ✅ System test before joining a conference\n\nPlease read the [documentation](https://github.com/nextcloud/jitsi)." : "Táto aplikácia integruje Jitsi konferencie do Nextcloud.\n\nVlastnosti:\n- 🎥 Jednoduché online konferencie v Nextcloud s využitím Jitsi\n- 🔗 Odkazy na zdieľané konferenčné miestnosti\n- 🔎 Zobrazuje konferenčné miestnosti v globálnom vyhľadávaní\n- ✅ Test systému pred vstupom na konferenciu\n\nPrečítajte si [dokumentáciu](https://github.com/nextcloud/jitsi).",
    "Loading …" : "Načítavam ...",
    "Server URL (required)" : "URL servera (vyžadované)",
    "Help link (optional)" : "Odkaz na pomoc (voliteľné)",
    "Display \"Join using the Jitsi app\"" : "Zobraziť \"Pripojiť pomocou aplikácie Jitsi\"",
    "JWT Secret (optional)" : "JWT tajný kľúč (voliteľné)",
    "JWT App ID" : "JWT ID aplikácie",
    "JWT Audience (optional)" : "JWT publikum (voliteľné)",
    "JWT Issuer (optional)" : "JWT vydavateľ (voliteľné)",
    "save" : "uložiť",
    "saved" : "uložené",
    "Saving …" : "Ukladám ...",
    "Please provide a Jitsi instance URL" : "Prosím zadajte URL inštancie Jistsi",
    "The server URL must start with https://" : "URL serveru musí začínať na https://",
    "It is highly recommended to set up a dedicated Jitsi instance" : "Dôrazne sa odporúča nastaviť dedikovanú inštanciu Jitsi",
    "Please provide the App ID" : "Prosím zadajte ID applikácie",
    "Failed to save settings" : "Nepodarilo sa uložiť nastavenia",
    "Failed to load settings" : "Nepodarilo sa načítať nastavenia",
    "Conference rooms" : "Konferenčné miestnosti",
    "Conference" : "Konferencia",
    "Conference left" : "Konferencia bola opustená",
    "Problems detected" : "Boli nájdené problémy",
    "Your browser is non-optimal:" : "Váš prehliadač nie je optimálny:",
    "Audio and video quality could be poor. It is recommended to use a recent <b>Firefox/Chrome/Chromium</b> version." : "Kvalita zvuku a videa môže byť nízka.<br> Odporúča sa použiť najnovšiu verziu <b>Firefox/Chrome/Chromium</b>.",
    "Browser not supported" : "Prehliadač nie je podporovaný",
    "Show system check" : "Zobraziť kontrolu systému",
    "Your name:" : "Vaše meno:",
    "Click here to join" : "Kliknite sem pre pripojenie",
    "Start muted" : "Spustiť so stlmeným mikrofónom",
    "Start with camera off" : "Spustiť s vypnutou kamerou",
    "Join with desktop app" : "Pripojiť s desktopovou aplikáciou",
    "Join with mobile app" : "Pripojiť s mobilnou aplikáciou",
    "App button not working?" : "Tlačítko aplikácie nefunguje?",
    "Download the desktop app here ↗" : "Stiahnite si destktopovú verziu tu ↗",
    "After successful installation try the button again." : "Po úspešnej inštalácii skúste tlačítko znova.",
    "Link copied" : "Odkaz skopírovaný",
    "Cannot copy, please copy the link manually" : "Nedarí sa skopírovať, skopírujte prosím ručne.",
    "Copy to clipboard" : "Skopírovať do schránky",
    "Browser" : "Prehliadač",
    "non-optimal" : "neoptimálne",
    "not supported" : "nepodporované",
    "Audio and video quality could be poor.<br> It is recommended to use a recent <b>Firefox/Chrome/Chromium</b> version." : "Kvalita zvuku a videa môže byť nízka.<br> Odporúča sa použiť najnovšiu verziu <b>Firefox/Chrome/Chromium</b>.",
    "Help" : "Pomoc",
    "Camera" : "Kamera",
    "Name of the new room" : "Názov novej miestnosti",
    "No conference rooms yet" : "Zatiaľ tu nie sú žiadne konferenčné miestnosti",
    "Create the first room:" : "Vytvoriť prvú miestnosť:",
    "Microphone" : "Mikrofón",
    "Join" : "Pripojiť",
    "Delete room" : "Zmazať miestnosť",
    "Room not found" : "Miestnosť nenájdená",
    "Please check the link/URL and ask your host" : "Zkontrolujte odkaz/URL a opýtajte sa vašeho hostiteľa",
    "Audio output" : "Zvukový výstup",
    "Play test sound" : "Prehrať testovací zvuk",
    "System check" : "Kontrola systému",
    "Got issues?" : "Mali ste problémy?",
    "Known problems / what you can try" : "Známe problémy / čo môžete vyskúšať",
    "• Accept the microphone/camera access permissions at the top of the screen" : "• Prijmite práva na prístup k mikrofónu/kamere v hornej časti obrazovky",
    "• Check the microphone/camera access permissions by clicking the icon next to the address bar. Then reload the page." : "• Kliknutím na ikonu vedľa panela s adresou skontrolujte prístupové práva na používanie mikrofónu/kamery. Potom znova načítajte stránku.",
    "• If you have DroidCam: Connect to the mobile camera, then reload the page" : "• Ak máte kameru DroidCam: Pripojte sa k mobilnej kamere a potom znova načítajte stránku",
    "• Try join using the Jitsi app (follow the instructions at the bottom of the page)" : "• Skúste sa pripojiť pomocou aplikácie Jitsi (postupujte podľa pokynov v spodnej časti stránky)",
    "No camera/microphone access" : "Žiadny prístup k fotoaparátu/mikrofónu",
    "Review your browser camera and microphone access settings" : "Skontrolujte nastavenia prístupu ku kamere a mikrofónu prehliadača",
    "Click here for {browser} instructions" : "Kliknutím sem zobrazíte pokyny pre prehliadač {browser}",
    "Does not work?" : "Nefunguje?",
    "Click here for troubleshooting help" : "Kliknite sem pre pomoc s riešením problémov",
    "Conferences app not yet configured" : "Aplikácie Konferencie nie je nakonfigurovaná",
    "Please contact your administrator to set up the conferences app." : "Požiadajte svojho správcu, aby povolil aplikáciu Konferencie.",
    "Your browser (%1$s) is outdated and<br>no longer supported" : "Váš prehliadač (%1$s) je zastaraný a<br>už nie je podporovaný",
    "It is recommended to use the latest version of one of the following browsers:" : "Odporúča sa používať najnovšiu verziu jedného z nasledujúcich prehliadačov:"
},
"nplurals=4; plural=(n % 1 == 0 && n == 1 ? 0 : n % 1 == 0 && n >= 2 && n <= 4 ? 1 : n % 1 != 0 ? 2: 3);");

==> nextcloud-jitsi-v0.19.0.tar.gz: jitsi/l10n/sk.js <==
OC.L10N.register(
    "jitsi",
    {
    "conferences" : "konferencie",
    "Jitsi Integration" : "Jitsi integrácia",
    "Conferences" : "Konferencie",
    "Jitsi Integration (unofficial)" : "Jitsi integrácia (neoficiálna)",
    "This app integrates Jitsi conferences into Nextcloud.\n\nFeatures:\n- 🎥 Easy online conferences in Nextcloud utilising Jitsi\n- 🔗 Sharable conference room links\n- 🔎 Shows conference rooms in the global search\n- ✅ System test before joining a conference\n\nPlease read the [documentation](https://github.com/nextcloud/jitsi)." : "Táto aplikácia integruje Jitsi konferencie do Nextcloud.\n\nVlastnosti:\n- 🎥 Jednoduché online konferencie v Nextcloud s využitím Jitsi\n- 🔗 Odkazy na zdieľané konferenčné miestnosti\n- 🔎 Zobrazuje konferenčné miestnosti v globálnom vyhľadávaní\n- ✅ Test systému pred vstupom na konferenciu\n\nPrečítajte si [dokumentáciu](https://github.com/nextcloud/jitsi).",
    "Loading …" : "Načítavam ...",
    "Server URL (required)" : "URL servera (vyžadované)",
    "Help link (optional)" : "Odkaz na pomoc (voliteľné)",
    "Display \"Join using the Jitsi app\"" : "Zobraziť \"Pripojiť pomocou aplikácie Jitsi\"",
    "JWT Secret (optional)" : "JWT tajný kľúč (voliteľné)",
    "JWT App ID" : "JWT ID aplikácie",
    "JWT Audience (optional)" : "JWT publikum (voliteľné)",
    "JWT Issuer (optional)" : "JWT vydavateľ (voliteľné)",
    "save" : "uložiť",
    "saved" : "uložené",
    "Saving …" : "Ukladám ...",
    "Please provide a Jitsi instance URL" : "Prosím zadajte URL inštancie Jistsi",
    "The server URL must start with https://" : "URL serveru musí začínať na https://",
    "It is highly recommended to set up a dedicated Jitsi instance" : "Dôrazne sa odporúča nastaviť dedikovanú inštanciu Jitsi",
    "Please provide the App ID" : "Prosím zadajte ID applikácie",
    "Failed to save settings" : "Nepodarilo sa uložiť nastavenia",
    "Failed to load settings" : "Nepodarilo sa načítať nastavenia",
    "Conference rooms" : "Konferenčné miestnosti",
    "Conference" : "Konferencia",
    "Conference left" : "Konferencia bola opustená",
    "Problems detected" : "Boli nájdené problémy",
    "Your browser is non-optimal:" : "Váš prehliadač nie je optimálny:",
    "Audio and video quality could be poor. It is recommended to use a recent <b>Firefox/Chrome/Chromium</b> version." : "Kvalita zvuku a videa môže byť nízka.<br> Odporúča sa použiť najnovšiu verziu <b>Firefox/Chrome/Chromium</b>.",
    "Browser not supported" : "Prehliadač nie je podporovaný",
    "Show system check" : "Zobraziť kontrolu systému",
    "Your name:" : "Vaše meno:",
    "Click here to join" : "Kliknite sem pre pripojenie",
    "Start muted" : "Spustiť so stlmeným mikrofónom",
    "Start with camera off" : "Spustiť s vypnutou kamerou",
    "Join with desktop app" : "Pripojiť s desktopovou aplikáciou",
    "Join with mobile app" : "Pripojiť s mobilnou aplikáciou",
    "App button not working?" : "Tlačítko aplikácie nefunguje?",
    "Download the desktop app here ↗" : "Stiahnite si destktopovú verziu tu ↗",
    "After successful installation try the button again." : "Po úspešnej inštalácii skúste tlačítko znova.",
    "Link copied" : "Odkaz bol skopírovaný",
    "Cannot copy, please copy the link manually" : "Nedarí sa skopírovať, skopírujte prosím ručne.",
    "Copy to clipboard" : "Skopírovať do schránky",
    "Browser" : "Prehliadač",
    "non-optimal" : "neoptimálne",
    "not supported" : "nepodporované",
    "Audio and video quality could be poor.<br> It is recommended to use a recent <b>Firefox/Chrome/Chromium</b> version." : "Kvalita zvuku a videa môže byť nízka.<br> Odporúča sa použiť najnovšiu verziu <b>Firefox/Chrome/Chromium</b>.",
    "Help" : "Pomoc",
    "Camera" : "Kamera",
    "Name of the new room" : "Názov novej miestnosti",
    "No conference rooms yet" : "Zatiaľ tu nie sú žiadne konferenčné miestnosti",
    "Create the first room:" : "Vytvoriť prvú miestnosť:",
    "Microphone" : "Mikrofón",
    "Join" : "Pripojiť",
    "Delete room" : "Zmazať miestnosť",
    "Room not found" : "Miestnosť nenájdená",
    "Please check the link/URL and ask your host" : "Zkontrolujte odkaz/URL a opýtajte sa vašeho hostiteľa",
    "Audio output" : "Zvukový výstup",
    "Play test sound" : "Prehrať testovací zvuk",
    "System check" : "Kontrola systému",
    "Got issues?" : "Mali ste problémy?",
    "Known problems / what you can try" : "Známe problémy / čo môžete vyskúšať",
    "• Accept the microphone/camera access permissions at the top of the screen" : "• Prijmite práva na prístup k mikrofónu/kamere v hornej časti obrazovky",
    "• Check the microphone/camera access permissions by clicking the icon next to the address bar. Then reload the page." : "• Kliknutím na ikonu vedľa panela s adresou skontrolujte prístupové práva na používanie mikrofónu/kamery. Potom znova načítajte stránku.",
    "• If you have DroidCam: Connect to the mobile camera, then reload the page" : "• Ak máte kameru DroidCam: Pripojte sa k mobilnej kamere a potom znova načítajte stránku",
    "• Try join using the Jitsi app (follow the instructions at the bottom of the page)" : "• Skúste sa pripojiť pomocou aplikácie Jitsi (postupujte podľa pokynov v spodnej časti stránky)",
    "No camera/microphone access" : "Žiadny prístup k fotoaparátu/mikrofónu",
    "Review your browser camera and microphone access settings" : "Skontrolujte nastavenia prístupu ku kamere a mikrofónu prehliadača",
    "Click here for {browser} instructions" : "Kliknutím sem zobrazíte pokyny pre prehliadač {browser}",
    "Does not work?" : "Nefunguje?",
    "Click here for troubleshooting help" : "Kliknite sem pre pomoc s riešením problémov",
    "Conferences app not yet configured" : "Aplikácie Konferencie nie je nakonfigurovaná",
    "Please contact your administrator to set up the conferences app." : "Požiadajte svojho správcu, aby povolil aplikáciu Konferencie.",
    "Your browser (%1$s) is outdated and<br>no longer supported" : "Váš prehliadač (%1$s) je zastaraný a<br>už nie je podporovaný",
    "It is recommended to use the latest version of one of the following browsers:" : "Odporúča sa používať najnovšiu verziu jedného z nasledujúcich prehliadačov:"
},
"nplurals=4; plural=(n % 1 == 0 && n == 1 ? 0 : n % 1 == 0 && n >= 2 && n <= 4 ? 1 : n % 1 != 0 ? 2: 3);");
